@@ -66,6 +66,10 @@ class JMan:
     def magatzems(self):
         return accions.Magatzems(con=self._con)
 
+    @property
+    def albarans(self):
+        return accions.Albarans(con=self._con)
+
 
 class JManFb:
     __slots__ = '_con'
