@@ -14,6 +14,8 @@ class Wms:
     _url_porta_palet = '/wms/palet_fora'
     _url_envia_palet = '/wms/palet_dins'
     _url_get_magatzem_ordre = '/magatzems_ordres/ex/{magatzem_ordre_id}'
+    _url_get_magatzems_ordres = '/magatzems_ordres'
+    _url_magatzem_ordre_finalitza = '/magatzems_ordres/{magatzem_ordre_id}/finalitza'
     _url_numero_unitat_logistica = '/comptadors/numero_unitat_logistica'
     _url_troba_magatzem_ordre = '/magatzems_ordres?numero_unitat_logistica={sscc}&' \
                                 'magatzem_entrada_id={magatzem_entrada_id}&finalitzades=false'
@@ -136,6 +138,14 @@ class Wms:
         res = self._con.get(url=Wms._url_get_magatzem_ordre.format(magatzem_ordre_id=p_magatzem_ordre_id))
         return res.json()
 
+    def get_magatzem_ordre_by_sscc(self, p_sscc: str):
+        res = self._con.get(url=Wms._url_get_magatzems_ordres + "?numero_unitat_logistica="+p_sscc+"&finalitzades=False")
+        return res.json()
+
     def nou_numero_unitat_logistica(self) -> str:
         res = self._con.post(url=Wms._url_numero_unitat_logistica, data=None)
         return res.text
+
+    def finalitza_magatzem_ortdre(self, p_magatzem_ordre_id: int):
+        res = self._con.put(url=Wms._url_magatzem_ordre_finalitza.format(magatzem_ordre_id=p_magatzem_ordre_id), data=None)
+        return res.text
