@@ -80,17 +80,19 @@ HAVING sum(cl.QUANTITAT) > 0
 """
 
 sync_comandes_pendents = """
-SELECT C.ID, C.NUMERO_COMANDA, C.DATA_COMANDA, T.NOM_LLARG_I_COMERCIAL
+SELECT C.ID, C.NUMERO_COMANDA, C.DATA_COMANDA,C.DATA_INSERCIO,C.REFERENCIA, T.NOM_LLARG_I_COMERCIAL
 FROM COMANDES C
 JOIN CLIENTS CL ON C.CLIENT_ID = CL.ID
 JOIN TERCERS T ON CL.TERCER_ID = T.ID
 JOIN COMANDES_DISTRIBUCIO CD ON C.ID = CD.COMANDA_ID
 left join SELECT_COMANDES_ESTATS_MAG(C.ID) CE ON C.ID = CE.COMANDA_ID
-where C.DATA_INICI IS NULL AND CE.MAG_PENDENT_SERVIR = 'S' AND C.DATA_ANULACIO IS NULL
-  and CD.REPARTIDOR_ID IS NOT NULL ;
+where C.DATA_INICI IS NULL 
+AND CE.MAG_PENDENT_SERVIR = 'S' 
+AND C.DATA_ANULACIO IS NULL
+and CD.REPARTIDOR_ID IS NOT NULL ;
 """
 
-sync_moviments_magatzems_pendents = """
+sync_magatzems_ordres_pendents = """
 SELECT MO.ID,MO.NUMERO_ORDRE, MO.DATA_INSERCIO, MO.MAGATZEM_ORDRE,MO.MAGATZEM_SORTIDA_ID, MO.MAGATZEM_ENTRADA_ID ,MO.OBSERVACIONS, U.NUMERO_UNITAT
 FROM MAGATZEMS_ORDRES MO
 JOIN MAGATZEMS_ORDRES_DETALL MD ON MO.ID = MD.MAGATZEM_ORDRE_ID
@@ -101,6 +103,13 @@ AND MO.DATA_FINALITZACIO IS NULL
 AND MO.MAGATZEM_ENTRADA_ID = ? ;
 """
 
+sync_moviments_magatzems_pendents = """
+select ma.id,ma.magatzem_origen_id,ma.magatzem_desti_id, ma.data_insercio,ma.data_peticio,ma.observacions
+from moviments_magatzems ma
+where ma.data_lliurament is null
+and ma.magatzem_origen_id = ? ;
+"""
+
 sync_clients_mrest = """
         select cl.id client_id_client,
         cl.codi_client,
